from distutils.core import setup

setup(name='suggestsoda',
      version='0.1.2',
      author='Daniel J Brooks',
      author_email='daniel.brooks@alumni.caltech.edu',
      license='Creative Commons Attribution-Noncommercial-Share Alike license',
      packages=['suggestsoda',],
      long_description=open("README.txt").read(),
     )